%define releasebase 3 
%define prefix /opt/gsl/%{version}
%define nbase gsl
%define modulepath /opt/Modules/modulefiles/
#Use as deafults if no command line inputs
%define as_limulus 1
# NOTE: compilers are mutually exclusive, only set one,
#       if not using command line options
#       ! only GNU compilers are supported at this time
#       ! others can be added as needed
%define use_gnu4  1
%define use_gnu3 0
%define use_pgi  0
%define use_intel 0
%define use_pathsc 0
# allow --with[out] <feature> at rpm command line build
%{?_with_gnu3: %{expand: %%define use_gnu3 1}}
%{?_with_gnu4: %{expand: %%define use_gnu4 1}}
%{?_with_pgi: %{expand: %%define use_pgi 1}}
%{?_with_intel: %{expand: %%define use_intel 1}}
%{?_with_pathsc: %{expand: %%define use_pathsc 1}}
%{?_with_basement: %{expand: %%define as_basement 1}}
%{?_with_limulus: %{expand: %%define as_limulus 1}}
#pick the target
%if "1" == "%{as_basement}"
%define targetbase Basement
%else
%define targetbase Limulus
%endif

%global _compiler_load  module load %{compilertag}
%global _compiler_unload  module unload %{compilertag}

Summary: The GNU Scientific Library
Version:  1.15
License: GPL
Group: %{targetbase}/Libraries
Release: %{releasebase}.%{targetbase}
URL: http://www.gnu.org/software/gsl
Packager: deadline@basement-supercomputing.com
Vendor: Basement Supercomputing.com
Source: %{nbase}-%{version}.tar.gz
Source1: gsl114/gsl-ref.html_node.tar.gz
Source2: gsl114/gsl-ref.ps.gz
Source3: gsl114/gsl-ref.txt.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Requires: modules
BuildRequires: modules

# is there a better way to do this?
%if "1" == "%{use_pgi}"
Name: %{nbase}-pgi
%define buildprefix %{prefix}/pgi
%define compilertag pgi
%define makeprefix  pgi
%define setenvs export CC=pgcc; export F77=pgf77; export CFLAGS='-fastsse -O3 '; export FFLAGS='-fastsse -O3 ';
%else
%if "1" == "%{use_intel}"
Name: %{nbase}-intel
%define compilertag intel
%define buildprefix %{prefix}/intel
%define makeprefix intel
%define setenvs export F77=ifort; export FFLAGS='-O3 ';export CC=icc;  export CFLAGS='-O3';
%else
%if "1" == "%{use_pathsc}"
Name: %{nbase}-pathsc
%define compilertag pathsc
%define buildprefix %{prefix}/pathsc
echo "Path Comp not implemented"
exit
%else
%if "1" == "%{use_gnu3}"
Name: %{nbase}-gnu3
%define compilertag gnu3
%define makeprefix gnu
%define buildprefix %{prefix}/gnu3
%define setenvs export CC=gcc; export CFLAGS='-O3'; export F77=g77; export FFLAGS='-O3';
%else
Name: %{nbase}-gnu4
%define compilertag gnu4
%define makeprefix gnu4
%define buildprefix %{prefix}/gnu4
%define setenvs export CC=gcc; export CFLAGS='-O3'; export F77=gfortran; export FFLAGS='-O3';
%endif
%endif
%endif
%endif

%define _libdir %{buildprefix}/lib

%description
The GNU Scientific Library (GSL) is a numerical library for C and C++ programmers. 
It is free software under the GNU General Public License.
The library provides a wide range of mathematical routines such as random number 
generators, special functions and least-squares fitting. There are over 1000 functions 
in total with an extensive test suite.

The complete range of subject areas covered by the library includes,
Complex Numbers             Roots of Polynomials     Special Functions
Vectors and Matrices        Permutations             Sorting
BLAS Support                Linear Algebra           Eigensystems
Fast Fourier Transforms     Quadrature               Random Numbers
Quasi-Random Sequences      Random Distributions     Statistics
Histograms                  N-Tuples                 Monte Carlo Integration
Simulated Annealing         Differential Equations   Interpolation
Numerical Differentiation   Chebyshev Approximation  Series Acceleration
Discrete Hankel Transforms  Root-Finding             Minimization
Least-Squares Fitting       Physical Constants       IEEE Floating-Point
Discrete Wavelet Transforms 		



%prep
%setup -b 0 -T  -n %{nbase}-%{version}

%build
rpm -qf /opt/Modules/bin/modulecmd >& /dev/null
if [ $? -ne 0 ]; then
  echo "This RPM requries the BSC Modules package to build"
fi
. /etc/profile.d/modules.sh
# there is no module for gnu4, gnu3, these are default
# the module command just fails to load these modules
# and continues with the gnu compilers, a bit ugly but it works
%{_compiler_load}
%setenvs
./configure --prefix=%{buildprefix}

make 
# un-comment to run the check
#make check
%{_compiler_unload}

%install
make  DESTDIR=%{buildroot} install

#Add the html, text, and PS manual for the docs
/bin/mkdir -p html
cd html
tar xvzf $RPM_SOURCE_DIR/gsl-ref.html_node.tar.gz
cd ..
/bin/cp $RPM_SOURCE_DIR/gsl-ref.ps.gz .
gunzip gsl-ref.ps.gz 
/bin/cp  $RPM_SOURCE_DIR/gsl-ref.txt.gz . 
gunzip  gsl-ref.txt.gz 
# include examples
cd doc
/bin/cp -r examples %{buildroot}/%{buildprefix}/share
cd ..

# create /opt//etc/ld.so.conf.d/
echo "Creating /opt//etc/ld.so.conf.d/%{name} file"
mkdir -p %{buildroot}/opt/etc/ld.so.conf.d
cat <<EOF> %{buildroot}/opt/etc/ld.so.conf.d/%{name}-%{version}.conf
%{_libdir}
EOF


#create the module file
mkdir -p %{buildroot}/%{modulepath}/%{nbase}/%{version}
cat <<EOF >%{buildroot}/%{modulepath}/%{nbase}/%{version}/%{compilertag}
#%Module1.0#######################################################################
## ${nbase} modulefile
##

proc ModulesHelp { } {
        puts stderr "\tThis module loads the appropriate environment for "
        puts stderr "\tusing %{name} version %{version}.\n"
}

module-whatis "%{name}  Version %{version}"
module-log error none

set gslroot /opt/gsl/%{version}/%{compilertag}

if [ module-info mode load ] {
  prepend-path  LD_LIBRARY_PATH \$gslroot/lib
	append-path MANPATH \$gslroot/man
	setenv GSL_PATH \$gslroot/lib
	setenv GSL_INCLUDE \$gslroot/include
}
if [ module-info mode remove ] {
  remove-path LD_LIBRARY_PATH \$gslroot/lib
	remove-path MANPATH \$gslroot/man
	unsetenv GSL_PATH 
	unsetenv GSL_INCLUDE 
}
EOF

%post
/sbin/ldconfig 2>/dev/null

%postun
/sbin/ldconfig 2>/dev/null

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc COPYING TODO BUGS INSTALL README AUTHORS THANKS NEWS  gsl-ref.ps gsl-ref.txt html
%{buildprefix}/bin/*
%{buildprefix}/lib/*
%{buildprefix}/include/*
%{buildprefix}/share/*
/opt/%{_sysconfdir}/ld.so.conf.d/%{name}-%{version}.conf
%{modulepath}/%{nbase}/%{version}/%{compilertag}
%changelog
* Fri Dec 12 2012  Douglas Eadline <deadline@basement-supercomputing.com>
- initial package


